Learn R Programming

SimEvolEnzCons (version 2.0.0)

RNV.graph.double.at.eq: Graph of e and RNV in relation to A at equilibrium

Description

Plot of RNV size and relative concentrations in relation to activities at equilibrium

Usage

RNV.graph.double.at.eq(list_eq,posi.legend="topleft",add.title=TRUE,
cex.lab=1,mar.lab=2.5,enz.lab=FALSE,...)

Arguments

list_eq

Output of function RNV.size.at.equilibr:

  • list_eq$A: Numeric vector of activities (length n)

  • list_eq$RNV_size: Numeric matrix of n column and 2 rows. Only first row will be used, corresponding to near RNV (small mutations).

  • list_eq$e_eq: Numeric vector of equilibrium (length n)

posi.legend

Character string. Where would you put legend? See parameter x in function legend. If NULL, legend will not appear.

add.title

Logical. Add a title to the plot?

cex.lab

Numeric. Size of axis label.

mar.lab

Numeric. Distance of label from axis.

enz.lab

Logical. Add enzyme name on graph?

...

Arguments to be passed to plot function, such cex or cex.lab

Value

Invisible data.frame of n rows (one by enzyme) and three columns ($A, $RNV and $e).

Details

list_eq$A, list_eq$RNV_size[1,] and list_eq$e_eq are binded in a data.frame of n rows (one by enzyme) and three columns (A, RNV and e), then ordered according to A.

Title (option add.title=TRUE) is "Comparing e and RNV at equilibrium".

See Also

See RNV.size.at.equilibr to compute RNV.

Examples

Run this code
# NOT RUN {
list_eq <- RNV.size.at.equilibr(20,"Comp",1000,Etot_0=100,show.plot=FALSE)
RNV.graph.double.at.eq(list_eq)



# }

Run the code above in your browser using DataLab