Learn R Programming

SimEvolEnzCons (version 2.0.0)

RNV.mean.suitability: Compare RNV mean in simulation with predicted RNV at equilibrium

Description

Compare RNV mean in simulation with predicted RNV at equilibrium to measure suitability of RNV mean as a proxy of RNV at equilibrium With a graph and a linear model.

Usage

RNV.mean.suitability(all_res_sim,end.mean=TRUE,which.sim=NULL,
new.window=FALSE,posi.legend="topleft",...)

Arguments

all_res_sim

List, the output of function simul.evol.enz.multiple (results of evolution simulation).

end.mean

Logical. If FALSE, compute RNV size mean for all rows of res_sim. If TRUE, compute RNV size mean for last half of res_sim rows.

which.sim

Numeric vector containing integer numbers between 1 and nsim. Which simulations would you represent? If NULL (default), all simulations would be represented.

new.window

Logical. Do graphics appear in a new window?

posi.legend

Character string. Where would you put the legend? See parameter x in function legend. If NULL, legend will not appear.

...

Arguments to be passed in plot function, such as lwd or cex.

Value

Invisible list of 6 elements:

  • $RNV_mean_simul: numeric matrix of n+2 columns and number of rows is between nsim and 2*nsim (depending on RNV number). n first columns contain RNV mean for corresponding enzyme. Column n+1 indicates simulation number and column n+2 the RNV number (1 for near RNV and 2 for far RNV).

  • $list_eq_all: list of nsim elements. Each element s is the output of function RNV.size.at.equilibr for simulation s

  • $RNV_at_eq: numeric matrix of n+1 columns and nsim rows. n first columns correspond to RNV size at predicted equilibrium for corresponding enzyme. Column n+1 indicates simulation number.

  • $lm_compar_RNV: object of class "lm". Linear model of RNV mean for near RNV (RNV number 1) in relation to RNV at predicted equilibrium.

  • $A_mean: numeric matrix of n columns (enzyme) and nsim rows (simulation). Each cell is the activity mean for each enzyme (in column) and each simulation (in row).

  • $Etot_mean: numeric vector of length nsim. Each value is the total concentration mean for each simulation.

Details

Function RNV.mean.suitability computes mean of RNV size by enzyme, using function RNV.mean.simul. It computes also the RNV size around predicted equilibrium, using function RNV.size.at.equilibr. Then RNV.mean.suitability plots the RNV means in relation to predicted RNVs for every enzyme and every simulation.

RNV.mean.suitability computes also a linear model of RNV means in relation to RNV size at equilibrium, for selected simulations only (by setting which.sim).

Each simulation corresponds to one color. Colors for simulations are taken in palette rainbow. Displayed number is the enzyme number. Black line is the linear model. Dashed line is the symmetry line.

Function RNV.mean.suitability is designed to compute mean RNV from simulations launched by simul.evol.enz.multiple. Input all_res_sim is the output of simul.evol.enz.multiple.

See Also

Function RNV.for.simul is used to compute RNV.

Function RNV.mean.simul is used to compute RNV mean for each simulation.

Function RNV.size.at.equilibr is used to compute RNV at equilibrium.

Examples

Run this code
# NOT RUN {
# With saved simulation
data(data_sim_SC)
RNV.mean.suitability(data_sim_SC,new.window=TRUE,which.sim=c(1,4,6))

# }
# NOT RUN {
data(data_sim_RegNeg)
RNV.mean.suitability(data_sim_RegNeg,new.window=TRUE)
# }
# NOT RUN {

# }

Run the code above in your browser using DataLab