Learn R Programming

SimEvolEnzCons (version 2.0.0)

coef_sel.discrete: Selection coefficient computation

Description

Computes the selection coefficient using the discrete expression \(s = (w^m - w^r)/w^r\)

Usage

coef_sel.discrete(E_res, A_res, E_mut=NULL, A_mut=NULL)

Arguments

E_res

Numeric vector of concentrations for the resident

A_res

Numeric vector of activities for the resident. Default value NULL corresponds to no mutation, i.e. same value as E_res

E_mut

Numeric vector of concentrations for the mutant

A_mut

Numeric vector of activities for the mutant. Default value NULL corresponds to no mutation, i.e. same value as A_res

Value

Numeric value for selection coefficient

Details

Computes the selection coefficient between mutant and resident using the discrete expression \(s = (w^m - w^r)/w^r\), assuming that fitness is proportional to flux. Here, function flux is used to compute the flux, and therefore, the fitness.

All input vectors need to have the same length.

If there is no mutation affecting concentrations (resp. activities), mutant concentrations (resp. activities) are identical to resident one. In this case, give to E_mut (resp. A_fun) the same value as E_res (resp. A_res), or put the default value NULL.

See Also

Use function activities to compute enzyme activities.

Examples

Run this code
# NOT RUN {
### Mutation of E
A <- c(1,10,30)
E <- c(30,30,30)
Em <- mut.E.direct(E,1,1,"SC")

coef_sel.discrete(E,A,Em)


### Mutation of A
E <- c(30,30,30)
kin <- c(1,10,1000)
Keq <- c(10,1,100)
A <- activities(kin,Keq)
kin_m <- mut.kin(kin,3,1)
Am <- activities(kin_m,Keq) #equilibrium constant cannot be modified by mutation

coef_sel.discrete(E,A,E,Am)


# }

Run the code above in your browser using DataLab