Learn R Programming

SimEvolEnzCons (version 2.0.0)

extract.tabEtot: Table of concentrations

Description

Creates a table of all absolute concentrations from simulation results, or any table of enzyme concentrations (enzyme by column)

Usage

extract.tabEtot(tabR,beta_fun)

Arguments

tabR

Dataframe of simulation results, which is an output of simul.evol.enz.multiple

beta_fun

Matrix of co-regulation coefficients

Value

Dataframe of \(n+p+2\) columns, where \(n\) is the number of enzymes and \(p\) is the number of regulation groups. The \(n\) first columns are the concentrations of enzymes 1 to \(n\) (named E1, ..., En), the following \(p\) are the sum of concentrations in regulations groups from group 1 to \(p\) (named Ep1, ..., Epp), the second last column is the total concentration (named Etot) and the last column is the simulation number (named sim). The column are named: E1, ..., En, Eq1, ... Eqp, Etot, sim. The row number of the output dataframe is the same as tabR. The last column "sim" is present only if input tabR has a column named "sim".

Details

From the result table tabR of simulations, extract the values of absolute concentrations of each enzymes, and computes the absolute concentrations \(E^q\) in each regulation and the total concentration at each time step.

The input tabR is the output tabR of function simul.evol.enz.multiple, or possibly the output res_sim of function simul.evol.enz.multiple.

The function also works for any table tabR that has \(n\) columns (enzyme concentrations in columns), and any number of rows. The last column "sim" is not an obligation, but if present, need to be the last column.

See Also

Use function simul.evol.enz.multiple to run simulations.

Examples

Run this code
# NOT RUN {
#one group
n <- 3
beta <- diag(1,n)
beta[1,2] <- 0.1 ; beta[2,1] <- 1/beta[1,2]
some.E <- matrix(30,ncol=n,nrow=3)
some.E[2,] <- c(20,50,10)
some.E[3,] <- runif(n,1,100)
tabEtot <- extract.tabEtot(some.E,beta)

# }
# NOT RUN {
#With saved simulation
data(data_sim_RegPos)
tabEtot <- extract.tabEtot(data_sim_RegPos$tabR,data_sim_RegPos$param$beta)
# }
# NOT RUN {

# }

Run the code above in your browser using DataLab