Learn R Programming

SimEvolEnzCons (version 2.0.0)

flux.shape.for.all.points: Flux shape computing for all points

Description

flux.shape.for.all.points computes flux and selection coefficient for various points (i.ei. vector of concentrations), giving the flux shape

Usage

flux.shape.for.all.points(Etot_fun, A_fun, nu_fun, correl_fun, beta_fun=NULL,
 E_ini_fun=NULL, n_fun=3)

Arguments

Etot_fun

Numeric. The total concentration

A_fun

Numeric vector of activities

nu_fun

Numeric value of canonical mutation effect

correl_fun

Character string indicating the abbreviation of the constraint applied on the system

beta_fun

Matrix of co-regulation coefficients

E_ini_fun

Numeric vector corresponding to initial concentrations.

n_fun

Numeric. Number of enzymes. Necessarily equal to 3 for this function.

Value

Invisible list of 3 elements:

  • $J : Numeric vector of flux.

  • $sel_disc : Numeric matrix of n_fun columns corresponding to discrete selection coefficient, and each row corresponds to one point (i.e. concentration vector). Each column correspond to the "mutated" enzyme.

  • $sel_cont :Same as $sel_disc, but for continuous selection coefficient. Same properties.

Details

Every enzyme correspond to one dimension in a n-dimensional graph.

For various concentration vectors, this function computes flux and selection coefficient.

Selection coefficient are computed from two different expressions (discrete by coef_sel.discrete and continuous by coef_sel.continue), for a mutation of canonical size nu_fun.

E_ini_fun is rescaled by a cross product to have sum of E_ini_fun equal to Etot_fun.

See Also

To study shape of flux only from a certain point and for any number of enzymes, see flux.shape.from.one.point