Learn R Programming

SimEvolEnzCons (version 2.0.0)

is.B.accurate: Verification of B accuracy

Description

Verifies if the vector B_fun of global co-regulation coefficients is accurate for other functions

Usage

is.B.accurate(B_fun, n_fun, correl_fun)

Arguments

B_fun

Numeric vector of global co-regulation coefficients

n_fun

Number of enzymes in the system

correl_fun

Character string indicating the constraint applied on the system

Value

Return TRUE if all conditions are respected, else stop

Details

Different tests are performed on parameter B_fun to verify its accuracy.

  • Is there regulation? If yes, B_fun is necessary.

  • Do B_fun have a correct length? Compare length(B_fun) and number of enzymes n_fun. If difference, stops.

  • Is there negative regulation in correl_fun? If yes, does B_fun include a negative regulation? If difference, stops.

  • Sum of 1/B_fun need to be equal an integer, which is the number of regulation groups.

See Also

To verify matrix of co-regulation coefficients, see function is.beta.accurate.

Examples

Run this code
# NOT RUN {
beta <- matrix(c(1,10,5,0.1,1,0.5,0.2,2,1),nrow=3)
B <- apply(beta,1,sumbis) 
is.B.accurate(B,3,"CRPos")


# }

Run the code above in your browser using DataLab