Learn R Programming

SimEvolEnzCons (version 2.0.0)

is.correl.authorized: Verification of constraint name

Description

Verifies if the constraint is authorized for other functions or not

Usage

is.correl.authorized(correl_fun)

Arguments

correl_fun

Character string indicating the abbreviation of the constraint applied on the system

Value

Returns TRUE if correl_fun is an authorized case, else stop

Details

Verifies if constraint is included in the six allowed cases.

Possible constraints are listed below:

  • "SC": independence between all enzymes

  • "Comp": competition for resources

  • "RegPos": positive regulation

  • "RegNeg": negative regulation

  • "CRPos": competition plus positive regulation

  • "CRNeg": competition plus negative regulation

See Also

Need help to correctly write correl_fun? Use function name.correl.

Examples

Run this code
# NOT RUN {
is.correl.authorized("SC")
#returns TRUE



# }

Run the code above in your browser using DataLab