Learn R Programming

SimEvolEnzCons (version 2.0.0)

search_group: Search the regulation group for an enzyme

Description

Give the number of the regulation group \(Phi_q\) where is the interest enzyme giving the list of regulation group

Usage

search_group(i,Lv)

Arguments

i

Integer which is the number of the interest enzyme

Lv

List of regulation group, preferably the output of function class_group

Value

Return an integer which is the number \(q\) of the group \(Phi_q\) that contains the interest enzyme

Details

Enzymes are classified in regulation groups depending on the co-regulation matrix (see function link{class_group}).

Function search_group also allows to find the group type from the list of group types. In that case, i is the interest group, and Lv is the list of group type, which the output of function group_types.

More largely, the function gives the number of a list element that contains a particular number.

See Also

Function class_group to compute the list of regulation groups

Examples

Run this code
# NOT RUN {
## One group
beta <- matrix(c(1,10,5,0.1,1,0.5,0.2,2,1),nrow=3)
L_Phi <- class_group(beta)

#enzyme 2 is in group 1
search_group(2,L_Phi)

## Two groups
n <- 3
beta <- diag(1,n) 
beta[1,2] <- -0.32 
beta[2,1] <- 1/beta[1,2]

L_Phi <- class_group(beta)

search_group(2,L_Phi) #gives 1 
search_group(3,L_Phi) #gives 2

# }

Run the code above in your browser using DataLab