list_eq$A: Numeric vector of activities (length n)
list_eq$RNV_size: Numeric matrix of n column and 2 rows. Only first row will be used, corresponding to near RNV (small mutations).
list_eq$e_eq: Numeric vector of equilibrium (length n)
posi.legend
Character string. Where would you put legend? See parameter x in function legend. If NULL, legend will not appear.
add.title
Logical. Add a title to the plot?
cex.lab
Numeric. Size of axis label.
mar.lab
Numeric. Distance of label from axis.
enz.lab
Logical. Add enzyme name on graph?
...
Arguments to be passed to plot function, such cex or cex.lab
Value
Invisible data.frame of n rows (one by enzyme) and three columns ($A, $RNV and $e).
Details
list_eq$A, list_eq$RNV_size[1,] and list_eq$e_eq are binded in a data.frame of n rows (one by enzyme) and three columns (A, RNV and e),
then ordered according to A.
Title (option add.title=TRUE) is "Comparing e and RNV at equilibrium".