powered by
Verifies if the vector B_fun of global co-regulation coefficients is accurate for other functions
B_fun
is.B.accurate(B_fun, n_fun, correl_fun)
Numeric vector of global co-regulation coefficients
Number of enzymes in the system
Character string indicating the constraint applied on the system
Return TRUE if all conditions are respected, else stop
TRUE
Different tests are performed on parameter B_fun to verify its accuracy.
Is there regulation? If yes, B_fun is necessary.
Do B_fun have a correct length? Compare length(B_fun) and number of enzymes n_fun. If difference, stops.
length(B_fun)
n_fun
Is there negative regulation in correl_fun? If yes, does B_fun include a negative regulation? If difference, stops.
correl_fun
Sum of 1/B_fun need to be equal an integer, which is the number of regulation groups.
1/B_fun
To verify matrix of co-regulation coefficients, see function is.beta.accurate.
is.beta.accurate
# NOT RUN { beta <- matrix(c(1,10,5,0.1,1,0.5,0.2,2,1),nrow=3) B <- apply(beta,1,sumbis) is.B.accurate(B,3,"CRPos") # }
Run the code above in your browser using DataLab