powered by
Verifies if the constraint is authorized for other functions or not
is.correl.authorized(correl_fun)
Character string indicating the abbreviation of the constraint applied on the system
Returns TRUE if correl_fun is an authorized case, else stop
correl_fun
Verifies if constraint is included in the six allowed cases.
Possible constraints are listed below:
"SC": independence between all enzymes
"SC"
"Comp": competition for resources
"Comp"
"RegPos": positive regulation
"RegPos"
"RegNeg": negative regulation
"RegNeg"
"CRPos": competition plus positive regulation
"CRPos"
"CRNeg": competition plus negative regulation
"CRNeg"
Need help to correctly write correl_fun? Use function name.correl.
name.correl
# NOT RUN { is.correl.authorized("SC") #returns TRUE # }
Run the code above in your browser using DataLab