(Utilitary function). Gives the result of the equation corresponding to discrete coefficient selection and indirect mutation of E
odd.discrete.sel.coef(delta_fun,i_fun,E_res,A_fun,alpha_fun,sel_coef_fun)Numeric value of the actual effect of a mutation targeting enzyme i_fun, i.e. \(\delta_i\)
Integer number indicating the enzyme targeted by the mutation
Numeric vector of resident enzyme concentrations
Numeric vector of activities
Numeric matrix of redistribution coefficients
Numeric value of selection coefficient
A numeric value
Gives the result of the equation corresponding to discrete coefficient selection and indirect mutation of E. Corresponding equation is \(\sum ( \frac{1}{A_j E_j} (\frac{1}{1 + s} - \frac{E_j}{E_j + \alpha_{ij} \delta_i} ) )\)
Null this equation corresponds to search the \(\delta_i\) corresponding to the given resident concentrations and selection coefficient.
This function is used to find \(\delta\) at bounds of the Range of Neutral Variation, where selection coefficient s is equal to \(+/-1/N\).
See function alpha_ij to compute the redistribution coefficients.